/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_Sha1State__40w7VnUMPOfQCNpx9axAOdw tyObject_Sha1State__40w7VnUMPOfQCNpx9axAOdw;
typedef struct tyTuple__oa1dFn55BmC688WoXKTtUg tyTuple__oa1dFn55BmC688WoXKTtUg;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ;
typedef struct tySequence__CZrkID0OnHjQpN63AqYJwg tySequence__CZrkID0OnHjQpN63AqYJwg;
typedef struct tySequence__qIo1GWQhO9cOgsAJDKUY8kw tySequence__qIo1GWQhO9cOgsAJDKUY8kw;
typedef struct tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA;
typedef struct tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA;
typedef struct tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf1;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph2;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend, void* ClE_0);
void* ClE_0;
} tyProc__h8IxK5anTqQTXvJUUElS3Q;
typedef N_CLOSURE_PTR(void, TM__hz3sEVFduMjVvdBnJCwMHA_6) (tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend);
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef N_CLOSURE_PTR(void, TM__hz3sEVFduMjVvdBnJCwMHA_9) (tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend);
typedef NU32 tyArray__xsE8WL1yT5DKfrMdYB89bYA[5];
typedef NU8 tyArray__w5VB8h5K8DB3oWrO5U2wqg[64];
struct tyObject_Sha1State__40w7VnUMPOfQCNpx9axAOdw {
NI count;
tyArray__xsE8WL1yT5DKfrMdYB89bYA state;
tyArray__w5VB8h5K8DB3oWrO5U2wqg buf;
};
typedef NU8 tyArray__YtcvxHNKV4YiecPE9ap1mcA[20];
typedef NU8 tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA;
struct tyTuple__oa1dFn55BmC688WoXKTtUg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA Field12;
};
typedef tyTuple__oa1dFn55BmC688WoXKTtUg tyArray__zAjcTh151RgaydpulQUcEQ[33];
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__HzVCwACFYM9cx9aV62PdjtuA;
typedef N_CLOSURE_PTR(void, TM__hz3sEVFduMjVvdBnJCwMHA_21) (void);
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
typedef NU8 tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ[14];
typedef NU8 tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA;
struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA {
  RootObj Sup;
NI counter;
tySequence__xv3aaFd3JCw8NbmALHiezQ* data;
tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA mode;
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NIM_BOOL Field2;
};
typedef NU8 tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A;
struct tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ {
tySequence__CZrkID0OnHjQpN63AqYJwg* data;
NI counter;
NI first;
NI last;
};
struct tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g {
NIM_BOOL isUnquoted;
tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A kind;
union{
struct {NimStringDesc* str;
} _kind_1;
struct {NI64 num;
} _kind_2;
struct {NF fnum;
} _kind_3;
struct {NIM_BOOL bval;
} _kind_4;
struct {tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ fields;
} _kind_6;
struct {tySequence__qIo1GWQhO9cOgsAJDKUY8kw* elems;
} _kind_7;
};
};
struct tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA {
NimStringDesc* Field0;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field1;
};
typedef tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyArray__z9aSJuvfp9bpSH4mIjAf4YJw[13];
typedef NU8 tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ;
struct tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA {
  RootObj Sup;
NI colonstate_;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph1;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s, void* buf, NI bufLen, void* ClE_0);
void* ClE_0;
} tyProc__M3d9crIwWf7vcamB5Yms8GQ;
typedef N_CLOSURE_PTR(NI, TM__hz3sEVFduMjVvdBnJCwMHA_58) (tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s, void* buf, NI bufLen, void* ClE_0);
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ {
NI Field0;
NI Field1;
NimStringDesc* Field2;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field3;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__qIo1GWQhO9cOgsAJDKUY8kw {
  TGenericSeq Sup;
  tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  TGenericSeq Sup;
  tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE];
};
struct tySequence__CZrkID0OnHjQpN63AqYJwg {
  TGenericSeq Sup;
  tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__KUEg0d7nz9cN9a2XtSOdwk6Q)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, clearPasses__passes_57)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(NF, epochTime__pureZtimes_3608)(void);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_CLOSURE(void, customizeForBackend__main_512)(tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_4)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_582)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_8)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__options_4185)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_112)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_CLOSURE(void, compileToBackend__main_534)(void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setOutFile__main_474)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
static N_INLINE(NIM_BOOL, isEmpty__options_4084)(NimStringDesc* x);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, hashMainCompilationParams__main_467)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, newSha1State__stdZsha49_10)(tyObject_Sha1State__40w7VnUMPOfQCNpx9axAOdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, update__stdZsha49_768)(tyObject_Sha1State__40w7VnUMPOfQCNpx9axAOdw* ctx, NIM_CHAR* data, NI dataLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetAppFilename)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4370)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___stdZsha49_870)(tyArray__YtcvxHNKV4YiecPE9ap1mcA self);
N_LIB_PRIVATE N_NIMCALL(void, finalize__stdZsha49_812)(tyObject_Sha1State__40w7VnUMPOfQCNpx9axAOdw* ctx, tyArray__YtcvxHNKV4YiecPE9ap1mcA Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
static N_INLINE(NimStringDesc*, libNameTmpl__main_476)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToC__main_363)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(void, initVars__extccomp_708)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, semanticPasses__main_38)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, registerPass__passes_63)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyTuple__nF9cH4hinXgGEUwO4G2bshw p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, verboseOpen__passaux_10)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, verboseProcess__passaux_33)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* context, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__sem_22328)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myProcess__sem_22542)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* context, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myClose__sem_22570)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* context, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__cgen_28590)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myProcess__cgen_28710)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myClose__cgen_28826)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, changeDetectedViaJsonBuildInstructions__extccomp_1847)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* jsonFile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, jsonBuildInstructionsFile__extccomp_1488)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ccHasSaneOverflow__extccomp_970)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, compileProject__modules_1214)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, NI32 projectFileIdx);
N_LIB_PRIVATE N_NIMCALL(void, cgenWriteModules__cgen_28849)(RootObj* backend, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(void, checkIntegrity__icZintegrity_699)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, generateCode__icZcbackend_464)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, callCCompiler__extccomp_1254)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, writeJsonBuildInstructions__extccomp_1507)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, writeDepsFile__main_40)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_90)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__systemZio_430)(NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
static N_INLINE(void, writeLine__msgs_442)(FILE* f, NimStringDesc** x, NI xLen_0);
N_LIB_PRIVATE N_NIMCALL(void, write__systemZio_205)(FILE* f, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NI, len__main_119)(tyObject_Table__BCPh85PHtwxox9bv7NLFrlg t);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__modulegraphs_9522)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, close__systemZio_217)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToJS__main_400)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(void, setTarget__platform_760)(tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA* t, tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw o, tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__jsgen_6826)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myProcess__jsgen_6665)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myClose__jsgen_6767)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(void, wantMainModule__modules_1209)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, loadConfigs__nimconf_267)(NimStringDesc* cfg, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(void, commandDoc__docgen_7231)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, setNoteDefaults__options_483)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note, NIM_BOOL enabled);
N_LIB_PRIVATE N_NIMCALL(void, commandDoc2__main_338)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__docgen_7225)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, assignIfDefault__main_317)(NI* result, NI val, NI def);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpenTex__docgen50_92)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, processNode__docgen50_61)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, close__docgen50_28)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpenJson__docgen50_102)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, processNodeJson__docgen50_66)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, closeJson__docgen50_49)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__docgen50_73)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(void, finishDoc2Pass__docgen50_115)(NimStringDesc* project);
N_LIB_PRIVATE N_NIMCALL(void, commandBuildIndex__docgen_7310)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* dir, NimStringDesc* outFile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4472)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, commandRst2Html__docgen_7261)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandRst2TeX__docgen_7264)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandJson__docgen_7267)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandTags__docgen_7289)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandGenDepend__main_307)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__depends_176)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, addDotDependency__depends_124)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, generateDot__depends_167)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, NimStringDesc* project);
N_LIB_PRIVATE N_NIMCALL(void, execExternalProgram__extccomp_810)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* cmd, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getConfigVar__options_4054)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJArray__pureZjson_133)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1809)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJObject__pureZjson_102)(void);
static N_INLINE(void, X5BX5Deq___pureZjson_1942)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* obj, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pureZjson_306)(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ* t, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1835)(NIM_BOOL b);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1838)(tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA* keyVals, NI keyValsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPrefixDir__options_4096)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_657)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ flags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___pureZjson_4484)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node);
N_LIB_PRIVATE N_NIMCALL(void, commandCheck__main_310)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(void, navDefinition__icZnavigator_367)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, navUsages__icZnavigator_369)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, navDefusages__icZnavigator_371)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, writeRodFiles__icZnavigator_373)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, parseFile__syntaxes_217)(NI32 fileIdx, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(void, commandView__main_463)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toAbsolute__pathutils_138)(NimStringDesc* file, NimStringDesc* base);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mainCommandArg__options_4044)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(void, rodViewer__icZic_9258)(NimStringDesc* rodfile, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache);
N_LIB_PRIVATE N_NIMCALL(void, commandInteractive__main_409)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
static N_NIMCALL(void, Marker_tyRef__BnTY2dJNiqeO8iju2BInZw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, interactivePasses__main_407)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(void, initDefines__condsyms_18)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__vm_14031)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myProcess__vm_14036)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myClose__vm_14041)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, compileSystemModule__modules_1203)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, compileModule__modules_33)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, NI32 fileIdx, tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fromModule);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_376)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, makeStdinModule__modules_1233)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, llStreamOpenStdIn__llstream_85)(tyProc__M3d9crIwWf7vcamB5Yms8GQ r, tyProc__HzVCwACFYM9cx9aV62PdjtuA onPrompt);
N_LIB_PRIVATE N_NIMCALL(NI, llReadFromStdin__llstream_81)(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s, void* buf, NI bufLen);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___main_437)(void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, flushDot__msgs_17)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processModule__passes_213)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stream);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, commandJsonScript__main_398)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(void, runJsonBuildInstructions__extccomp_2595)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* jsonFile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dump__vmprofiler_697)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* pd);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genSuccessX__msgs_1537)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIobject__jLKPtdbDCz7KEj3NDIo2qQ_;
extern TNimType NTIint__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_;
extern TNimType NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_;
N_LIB_PRIVATE TNimType NTIrefobject__KUEg0d7nz9cN9a2XtSOdwk6Q_;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
extern TNimType NTItbackend__zoooocqvga73vZuhGAAy6A_;
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_3, "true", 4);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_4, "useNimRtl", 9);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_5, "main.nim(242, 33) `false` ", 26);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_7, "main.nim(272, 14) `ret.string.isAbsolute` ", 42);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_8, "htmldocs", 8);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_10, "_", 1);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_11, ".js", 3);
extern NIM_CONST tyArray__zAjcTh151RgaydpulQUcEQ OS__platform_518;
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_12, "$1.lib", 6);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_13, "lib$1.a", 7);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_14, "nimBetterRun", 12);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_15, "nimEmulateOverflowChecks", 24);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_16, "nimIcIntegrityChecks", 20);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_17, ".deps", 5);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_18, "\012", 1);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_19, "ecmascript", 10);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_20, "main.nim(252, 33) `false` ", 26);
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_22, "\'run\' command not available; rebuild with -d:tinyc", 50);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_24, "/home/runner/work/nightlies/nightlies/nim/compiler/main.nim", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__hz3sEVFduMjVvdBnJCwMHA_23 = {((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_24),
((NI) 286),
((NI) 16)}
;
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_25, "nimdoc.tex.cfg", 14);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_26, "nimdoc.cfg", 10);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_27, "nimdoc", 6);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_28, "tex", 3);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_29, "json", 4);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_30, "html", 4);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_31, "main.nim(84, 20) `false` ", 25);
static NIM_CONST tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ TM__hz3sEVFduMjVvdBnJCwMHA_32 = {
0x00, 0x00, 0x00, 0xfc, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_33, "dot -Tpng -o", 12);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_34, "png", 3);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_35, "dot", 3);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_36, "dump.format", 11);
extern TNimType NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_;
extern TNimType NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_;
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_37, "version", 7);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_38, "1.6.14", 6);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_39, "nimExe", 6);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_40, "prefixdir", 9);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_41, "libpath", 7);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_42, "project_path", 12);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_43, "defined_symbols", 15);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_44, "lib_paths", 9);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_45, "lazyPaths", 9);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_46, "outdir", 6);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_47, "out", 3);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_48, "nimcache", 8);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_49, "hints", 5);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_50, "warnings", 8);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_51, "-- list of currently defined symbols --", 39);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_52, "-- end of list --", 17);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_53, "nimcheck", 8);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_54, "nimscript", 9);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_55, "nimconfig", 9);
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_56, "rod", 3);
N_LIB_PRIVATE TNimType NTIobject__9a3nhy8WNV5ikCoayUArgTA_;
N_LIB_PRIVATE TNimType NTIrefobject__BnTY2dJNiqeO8iju2BInZw_;
extern TNimType NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_;
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_59, "NimScript file does not exist: ", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__hz3sEVFduMjVvdBnJCwMHA_60 = {((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_24),
((NI) 382),
((NI) 16)}
;
STRING_LITERAL(TM__hz3sEVFduMjVvdBnJCwMHA_61, "invalid command: ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__hz3sEVFduMjVvdBnJCwMHA_62 = {((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_24),
((NI) 389),
((NI) 14)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
static N_NIMCALL(void, Marker_tyRef__KUEg0d7nz9cN9a2XtSOdwk6Q)(void* p, NI op) {
	tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ* a;
	a = (tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ*)p;
	nimGCvisit((void*)(*a).conf1, op);
	nimGCvisit((void*)(*a).graph2, op);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
N_LIB_PRIVATE N_CLOSURE(void, customizeForBackend__main_512)(tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend, void* ClE_0) {
	tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ* colonenvP_;
	colonenvP_ = (tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ*) ClE_0;
	{
		if (!((*(*colonenvP_).conf1).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 0))) goto LA3_;
		(*(*colonenvP_).conf1).backend = backend;
	}
	LA3_: ;
	defineSymbol__condsyms_4((*(*(*colonenvP_).graph2).config).symbols, reprEnum((NI)(*(*colonenvP_).conf1).backend, (&NTItbackend__zoooocqvga73vZuhGAAy6A_)), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
	switch ((*(*colonenvP_).conf1).backend) {
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 1):
	{
		{
			if (!((*(*colonenvP_).conf1).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 0))) goto LA8_;
			(*(*colonenvP_).conf1).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 1);
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2):
	{
		{
			if (!((*(*colonenvP_).conf1).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 0))) goto LA13_;
			(*(*colonenvP_).conf1).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 2);
		}
		LA13_: ;
	}
	break;
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 4):
	{
	}
	break;
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3):
	{
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = hcrOn__options_582((*colonenvP_).conf1);
			if (!T19_) goto LA20_;
			undefSymbol__condsyms_8((*(*colonenvP_).conf1).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_4));
		}
		LA20_: ;
	}
	break;
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 0):
	{
		{
			if (!NIM_TRUE) goto LA25_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_5));
		}
		LA25_: ;
	}
	break;
	}
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__options_4084)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, hashMainCompilationParams__main_467)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	tyObject_Sha1State__40w7VnUMPOfQCNpx9axAOdw state;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	tyArray__YtcvxHNKV4YiecPE9ap1mcA T3_;
	result = NIM_NIL;
	nimZeroMem((void*)(&state), sizeof(tyObject_Sha1State__40w7VnUMPOfQCNpx9axAOdw));
	newSha1State__stdZsha49_10((&state));
	T1_ = NIM_NIL;
	T1_ = nosgetAppFilename();
	update__stdZsha49_768((&state), (T1_) ? (T1_->data) : NIM_NIL, (T1_ ? T1_->Sup.len : 0));
	update__stdZsha49_768((&state), ((*conf).commandLine) ? ((*conf).commandLine->data) : NIM_NIL, ((*conf).commandLine ? (*conf).commandLine->Sup.len : 0));
	T2_ = NIM_NIL;
	T2_ = dollar___options_4370((*conf).projectFull);
	update__stdZsha49_768((&state), (T2_) ? (T2_->data) : NIM_NIL, (T2_ ? T2_->Sup.len : 0));
	nimZeroMem((void*)T3_, sizeof(tyArray__YtcvxHNKV4YiecPE9ap1mcA));
	finalize__stdZsha49_812((&state), T3_);
	result = dollar___stdZsha49_870(T3_);
	return result;
}
static N_INLINE(NimStringDesc*, libNameTmpl__main_476)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		if (!((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 2))) goto LA3_;
		result = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_12));
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_13));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setOutFile__main_474)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		NIM_BOOL T3_;
		NimStringDesc* base;
		NimStringDesc* targetName;
		NimStringDesc* T26_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__options_4084((*conf).outFile);
		if (!T3_) goto LA4_;
		base = copyString((*conf).projectName);
		{
			NimStringDesc* T10_;
			NimStringDesc* T11_;
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 13))&63U)))!=0)) goto LA8_;
			T10_ = NIM_NIL;
			T11_ = NIM_NIL;
			T11_ = hashMainCompilationParams__main_467(conf);
			T10_ = rawNewString((T11_ ? T11_->Sup.len : 0) + 1);
appendString(T10_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_10));
appendString(T10_, T11_);
			base = resizeString(base, (T10_ ? T10_->Sup.len : 0) + 0);
appendString(base, T10_);
		}
		LA8_: ;
		{
			NimStringDesc* T16_;
			if (!((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3))) goto LA14_;
			T16_ = NIM_NIL;
			T16_ = rawNewString((base ? base->Sup.len : 0) + 3);
appendString(T16_, base);
appendString(T16_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_11));
			targetName = T16_;
		}
		goto LA12_;
		LA14_: ;
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 7))&63U)))!=0)) goto LA18_;
			targetName = nsuFormatSingleElem(OS__platform_518[((*conf).target.targetOS)- 1].Field2, base);
		}
		goto LA12_;
		LA18_: ;
		{
			NimStringDesc* T23_;
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 8))&63U)))!=0)) goto LA21_;
			T23_ = NIM_NIL;
			T23_ = libNameTmpl__main_476(conf);
			targetName = nsuFormatSingleElem(T23_, base);
		}
		goto LA12_;
		LA21_: ;
		{
			NimStringDesc* T25_;
			T25_ = NIM_NIL;
			T25_ = rawNewString((base ? base->Sup.len : 0) + (OS__platform_518[((*conf).target.targetOS)- 1].Field10 ? OS__platform_518[((*conf).target.targetOS)- 1].Field10->Sup.len : 0) + 0);
appendString(T25_, base);
appendString(T25_, OS__platform_518[((*conf).target.targetOS)- 1].Field10);
			targetName = T25_;
		}
		LA12_: ;
		T26_ = NIM_NIL;
		T26_ = (*conf).outFile; (*conf).outFile = copyStringRC1(targetName);
		if (T26_) nimGCunrefNoCycle(T26_);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, semanticPasses__main_38)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T1_;
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T2_;
	T1_.Field0 = verboseOpen__passaux_10;
	T1_.Field1 = verboseProcess__passaux_33;
	T1_.Field2 = NIM_NIL;
	T1_.Field3 = NIM_FALSE;
	registerPass__passes_63(g, T1_);
	T2_.Field0 = myOpen__sem_22328;
	T2_.Field1 = myProcess__sem_22542;
	T2_.Field2 = myClose__sem_22570;
	T2_.Field3 = NIM_TRUE;
	registerPass__passes_63(g, T2_);
}
static N_INLINE(void, writeLine__msgs_442)(FILE* f, NimStringDesc** x, NI xLen_0) {
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < xLen_0)) goto LA3;
				i = (&x[i_2]);
				write__systemZio_205(f, (*i));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	write__systemZio_205(f, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_18));
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeDepsFile__main_40)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	NimStringDesc* fname;
	NimStringDesc* T1_;
	FILE* f;
	T1_ = NIM_NIL;
	T1_ = rawNewString(((*(*g).config).projectName ? (*(*g).config).projectName->Sup.len : 0) + 5);
appendString(T1_, (*(*g).config).projectName);
appendString(T1_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_17));
	fname = slash___pathutils_90((*(*g).config).nimcacheDir, T1_);
	f = open__systemZio_430(fname, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 1), ((NI) -1));
	{
		tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ* m;
		NI i;
		NI L;
		NI T3_;
		m = (tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ*)0;
		i = ((NI) 0);
		T3_ = ((*g).ifaces ? (*g).ifaces->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i < L)) goto LA5;
				m = (&(*g).ifaces->data[i]);
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T10_;
					if (!!(((*m).module == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA8_;
					nimZeroMem((void*)T10_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T10_[0] = toFullPath__msgs_548((*g).config, ((NI32) ((*(*m).module).position)));
					writeLine__msgs_442(f, T10_, 1);
				}
				LA8_: ;
				i += ((NI) 1);
			} LA5: ;
		}
	}
	{
		NI32* k;
		NI L_2;
		k = (NI32*)0;
		L_2 = len__main_119((*g).inclToMod);
		{
			NI h;
			NI colontmp_;
			NI T13_;
			NI res;
			h = (NI)0;
			colontmp_ = (NI)0;
			T13_ = (((*g).inclToMod.data ? (*g).inclToMod.data->Sup.len : 0)-1);
			colontmp_ = T13_;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA15;
					h = res;
					{
						NIM_BOOL T18_;
						T18_ = (NIM_BOOL)0;
						T18_ = isFilled__pureZcollectionsZtables_31((*g).inclToMod.data->data[h].Field0);
						if (!T18_) goto LA19_;
						k = (&(*g).inclToMod.data->data[h].Field1);
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T23_;
							tyArray__nHXaesL0DJZHyVS07ARPRA T26_;
							T23_ = NIM_NIL;
							T23_ = getModule__modulegraphs_9522(g, (*k));
							if (!(T23_ == 0)) goto LA24_;
							nimZeroMem((void*)T26_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
							T26_[0] = toFullPath__msgs_548((*g).config, (*k));
							writeLine__msgs_442(f, T26_, 1);
						}
						LA24_: ;
					}
					LA19_: ;
					res += ((NI) 1);
				} LA15: ;
			}
		}
	}
	close__systemZio_217(f);
}
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToC__main_363)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf;
{	conf = (*graph).config;
	initVars__extccomp_708(conf);
	semanticPasses__main_38(graph);
	{
		tyTuple__nF9cH4hinXgGEUwO4G2bshw T5_;
		if (!((*conf).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0))) goto LA3_;
		T5_.Field0 = myOpen__cgen_28590;
		T5_.Field1 = myProcess__cgen_28710;
		T5_.Field2 = myClose__cgen_28826;
		T5_.Field3 = NIM_FALSE;
		registerPass__passes_63(graph, T5_);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = ((4098 & (*conf).globalOptions) == 4096);
			if (T8_) goto LA9_;
			T8_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_14));
			LA9_: ;
			if (!T8_) goto LA10_;
			{
				NimStringDesc* T14_;
				NIM_BOOL T15_;
				T14_ = NIM_NIL;
				T14_ = jsonBuildInstructionsFile__extccomp_1488(conf);
				T15_ = (NIM_BOOL)0;
				T15_ = changeDetectedViaJsonBuildInstructions__extccomp_1847(conf, T14_);
				if (!!(T15_)) goto LA16_;
				nimCopyMem((void*)(*(*graph).config).notes, (NIM_CONST void*)(*(*graph).config).mainPackageNotes, 12);
				goto BeforeRet_;
			}
			LA16_: ;
		}
		LA10_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = ccHasSaneOverflow__extccomp_970(conf);
		if (!!(T20_)) goto LA21_;
		defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_15), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
	}
	LA21_: ;
	compileProject__modules_1214(graph, ((NI32) -1));
	{
		if (!(((NI) 0) < (*(*graph).config).errorCounter)) goto LA25_;
		goto BeforeRet_;
	}
	LA25_: ;
	{
		if (!((*conf).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0))) goto LA29_;
		cgenWriteModules__cgen_28849((*graph).backend, conf);
	}
	goto LA27_;
	LA29_: ;
	{
		{
			NIM_BOOL T34_;
			T34_ = (NIM_BOOL)0;
			T34_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_16));
			if (!T34_) goto LA35_;
			checkIntegrity__icZintegrity_699(graph);
		}
		LA35_: ;
		generateCode__icZcbackend_464(graph);
		{
			if (!!(((*graph).backend == ((RootObj*) NIM_NIL)))) goto LA39_;
			cgenWriteModules__cgen_28849((*graph).backend, conf);
		}
		LA39_: ;
	}
	LA27_: ;
	{
		NIM_BOOL T43_;
		T43_ = (NIM_BOOL)0;
		T43_ = !(((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 7)));
		if (!(T43_)) goto LA44_;
		T43_ = !(((*graph).backend == ((RootObj*) NIM_NIL)));
		LA44_: ;
		if (!T43_) goto LA45_;
		callCCompiler__extccomp_1254(conf);
		{
			NIM_BOOL T49_;
			T49_ = (NIM_BOOL)0;
			T49_ = hcrOn__options_582(conf);
			if (!!(T49_)) goto LA50_;
			writeJsonBuildInstructions__extccomp_1507(conf);
		}
		LA50_: ;
		{
			if (!(((*(*graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 10))&63U)))!=0)) goto LA54_;
			writeDepsFile__main_40(graph);
		}
		LA54_: ;
	}
	LA45_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToJS__main_400)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf;
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T1_;
	conf = (*graph).config;
	(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 2);
	setTarget__platform_760((&(*conf).target), ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 27), ((tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ) 16));
	defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_19), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
	semanticPasses__main_38(graph);
	T1_.Field0 = myOpen__jsgen_6826;
	T1_.Field1 = myProcess__jsgen_6665;
	T1_.Field2 = myClose__jsgen_6767;
	T1_.Field3 = NIM_FALSE;
	registerPass__passes_63(graph, T1_);
	compileProject__modules_1214(graph, ((NI32) -1));
	{
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 10))&63U)))!=0)) goto LA4_;
		writeDepsFile__main_40(graph);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, compileToBackend__main_534)(void* ClE_0) {
	tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ* colonenvP_;
	tyProc__h8IxK5anTqQTXvJUUElS3Q T1_;
	colonenvP_ = (tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ*) ClE_0;
	nimZeroMem((void*)(&T1_), sizeof(tyProc__h8IxK5anTqQTXvJUUElS3Q));
	T1_.ClP_0 = customizeForBackend__main_512; T1_.ClE_0 = colonenvP_;
	T1_.ClE_0? T1_.ClP_0((*(*colonenvP_).conf1).backend, T1_.ClE_0):((TM__hz3sEVFduMjVvdBnJCwMHA_9)(T1_.ClP_0))((*(*colonenvP_).conf1).backend);
	setOutFile__main_474((*colonenvP_).conf1);
	switch ((*(*colonenvP_).conf1).backend) {
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 1):
	{
		commandCompileToC__main_363((*colonenvP_).graph2);
	}
	break;
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2):
	{
		commandCompileToC__main_363((*colonenvP_).graph2);
	}
	break;
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 4):
	{
		commandCompileToC__main_363((*colonenvP_).graph2);
	}
	break;
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3):
	{
		commandCompileToJS__main_400((*colonenvP_).graph2);
	}
	break;
	case ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 0):
	{
		{
			if (!NIM_TRUE) goto LA9_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_20));
		}
		LA9_: ;
	}
	break;
	}
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, commandDoc2__main_338)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, NimStringDesc* ext) {
	NI T1_;
	handleDocOutputOptions__docgen_7225((*graph).config);
	T1_ = (NI)0;
	assignIfDefault__main_317((&(*(*graph).config).errorMax), ((NI) 2147483647), T1_);
	semanticPasses__main_38(graph);
	if (eqStrings(ext, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_28))) goto LA2_;
	if (eqStrings(ext, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_29))) goto LA3_;
	if (eqStrings(ext, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_30))) goto LA4_;
	goto LA5_;
	LA2_: ;
	{
		tyTuple__nF9cH4hinXgGEUwO4G2bshw T8_;
		T8_.Field0 = myOpenTex__docgen50_92;
		T8_.Field1 = processNode__docgen50_61;
		T8_.Field2 = close__docgen50_28;
		T8_.Field3 = NIM_FALSE;
		registerPass__passes_63(graph, T8_);
	}
	goto LA6_;
	LA3_: ;
	{
		tyTuple__nF9cH4hinXgGEUwO4G2bshw T10_;
		T10_.Field0 = myOpenJson__docgen50_102;
		T10_.Field1 = processNodeJson__docgen50_66;
		T10_.Field2 = closeJson__docgen50_49;
		T10_.Field3 = NIM_FALSE;
		registerPass__passes_63(graph, T10_);
	}
	goto LA6_;
	LA4_: ;
	{
		tyTuple__nF9cH4hinXgGEUwO4G2bshw T12_;
		T12_.Field0 = myOpen__docgen50_73;
		T12_.Field1 = processNode__docgen50_61;
		T12_.Field2 = close__docgen50_28;
		T12_.Field3 = NIM_FALSE;
		registerPass__passes_63(graph, T12_);
	}
	goto LA6_;
	LA5_: ;
	{
		{
			NimStringDesc* T18_;
			if (!NIM_TRUE) goto LA16_;
			T18_ = NIM_NIL;
			T18_ = rawNewString((ext ? ext->Sup.len : 0) + 25);
appendString(T18_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_31));
appendString(T18_, ext);
			failedAssertImpl__systemZassertions_56(T18_);
		}
		LA16_: ;
	}
	LA6_: ;
	compileProject__modules_1214(graph, ((NI32) -1));
	finishDoc2Pass__docgen50_115((*(*graph).config).projectName);
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, commandGenDepend__main_307)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T1_;
	NimStringDesc* project;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	NimStringDesc* T4_;
	semanticPasses__main_38(graph);
	T1_.Field0 = myOpen__depends_176;
	T1_.Field1 = addDotDependency__depends_124;
	T1_.Field2 = NIM_NIL;
	T1_.Field3 = NIM_FALSE;
	registerPass__passes_63(graph, T1_);
	compileProject__modules_1214(graph, ((NI32) -1));
	project = (*(*graph).config).projectFull;
	writeDepsFile__main_40(graph);
	generateDot__depends_167(graph, project);
	T2_ = NIM_NIL;
	T3_ = NIM_NIL;
	T3_ = noschangeFileExt(project, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_34));
	T4_ = NIM_NIL;
	T4_ = noschangeFileExt(project, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_35));
	T2_ = rawNewString((T3_ ? T3_->Sup.len : 0) + (T4_ ? T4_->Sup.len : 0) + 13);
appendString(T2_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_33));
appendString(T2_, T3_);
appendChar(T2_, 32);
appendString(T2_, T4_);
	execExternalProgram__extccomp_810((*graph).config, T2_, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 93));
}
static N_INLINE(void, X5BX5Deq___pureZjson_1942)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* obj, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val) {
	X5BX5Deq___pureZjson_306((&(*obj)._kind_6.fields), key, val);
}
N_LIB_PRIVATE N_NIMCALL(void, commandCheck__main_310)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf;
	NI T1_;
	conf = (*graph).config;
	T1_ = (NI)0;
	assignIfDefault__main_317((&(*conf).errorMax), ((NI) 2147483647), T1_);
	defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_53), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
	{
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0)) goto LA4_;
		defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_54), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
		defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_55), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
	}
	LA4_: ;
	semanticPasses__main_38(graph);
	compileProject__modules_1214(graph, ((NI32) -1));
	{
		if (!!(((*conf).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA8_;
		switch ((*conf).ideCmd) {
		case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 3):
		{
			navDefinition__icZnavigator_367(graph);
		}
		break;
		case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 4):
		{
			navUsages__icZnavigator_369(graph);
		}
		break;
		case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 5):
		{
			navDefusages__icZnavigator_371(graph);
		}
		break;
		default:
		{
		}
		break;
		}
		writeRodFiles__icZnavigator_373(graph);
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandView__main_463)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	NimStringDesc* f;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	T1_ = NIM_NIL;
	T1_ = mainCommandArg__options_4044((*graph).config);
	T2_ = NIM_NIL;
	T2_ = nosgetCurrentDir();
	T3_ = NIM_NIL;
	T3_ = toAbsolute__pathutils_138(T1_, T2_);
	f = nosaddFileExt(T3_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_56));
	rodViewer__icZic_9258(f, (*graph).config, (*graph).cache);
}
static N_NIMCALL(void, Marker_tyRef__BnTY2dJNiqeO8iju2BInZw)(void* p, NI op) {
	tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA* a;
	a = (tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA*)p;
	nimGCvisit((void*)(*a).graph1, op);
}
N_LIB_PRIVATE N_NIMCALL(void, interactivePasses__main_407)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T1_;
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T2_;
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T3_;
	initDefines__condsyms_18((*(*graph).config).symbols);
	defineSymbol__condsyms_4((*(*graph).config).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_54), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
	T1_.Field0 = verboseOpen__passaux_10;
	T1_.Field1 = verboseProcess__passaux_33;
	T1_.Field2 = NIM_NIL;
	T1_.Field3 = NIM_FALSE;
	registerPass__passes_63(graph, T1_);
	T2_.Field0 = myOpen__sem_22328;
	T2_.Field1 = myProcess__sem_22542;
	T2_.Field2 = myClose__sem_22570;
	T2_.Field3 = NIM_TRUE;
	registerPass__passes_63(graph, T2_);
	T3_.Field0 = myOpen__vm_14031;
	T3_.Field1 = myProcess__vm_14036;
	T3_.Field2 = myClose__vm_14041;
	T3_.Field3 = NIM_FALSE;
	registerPass__passes_63(graph, T3_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___main_437)(void* ClE_0) {
	tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA* colonenvP_;
	colonenvP_ = (tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA*) ClE_0;
	flushDot__msgs_17((*(*colonenvP_).graph1).config);
}
N_LIB_PRIVATE N_NIMCALL(void, commandInteractive__main_409)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA* colonenv_;
	NI T1_;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA*) newObj((&NTIrefobject__BnTY2dJNiqeO8iju2BInZw_), sizeof(tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA));
	(*colonenv_).Sup.m_type = (&NTIobject__9a3nhy8WNV5ikCoayUArgTA_);
	asgnRef((void**) (&(*colonenv_).graph1), graph);
	T1_ = (NI)0;
	assignIfDefault__main_317((&(*(*(*colonenv_).graph1).config).errorMax), ((NI) 2147483647), T1_);
	interactivePasses__main_407((*colonenv_).graph1);
	compileSystemModule__modules_1203((*colonenv_).graph1);
	{
		NI T4_;
		NI32 T7_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T8_;
		T4_ = ((*(*(*colonenv_).graph1).config).commandArgs ? (*(*(*colonenv_).graph1).config).commandArgs->Sup.len : 0);
		if (!(((NI) 0) < T4_)) goto LA5_;
		T7_ = (NI32)0;
		T7_ = fileInfoIdx__msgs_376((*(*colonenv_).graph1).config, (*(*(*colonenv_).graph1).config).projectFull);
		T8_ = NIM_NIL;
		T8_ = compileModule__modules_33((*colonenv_).graph1, T7_, 0, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
		(void)(T8_);
	}
	goto LA2_;
	LA5_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
		tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
		tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* T10_;
		tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s;
		tyProc__M3d9crIwWf7vcamB5Yms8GQ T11_;
		tyProc__HzVCwACFYM9cx9aV62PdjtuA T12_;
		NIM_BOOL T13_;
		m = makeStdinModule__modules_1233((*colonenv_).graph1);
		(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14)) & 63);
		T10_ = NIM_NIL;
		T10_ = (tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg*) newObj((&NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_), sizeof(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg));
		(*T10_).module = (*m).Sup.itemId.module;
		(*T10_).symId = (*m).Sup.itemId.item;
		(*T10_).typeId_0 = ((NI32) 0);
		idgen = T10_;
		nimZeroMem((void*)(&T11_), sizeof(tyProc__M3d9crIwWf7vcamB5Yms8GQ));
		T11_.ClP_0 = ((TM__hz3sEVFduMjVvdBnJCwMHA_58) (llReadFromStdin__llstream_81)); T11_.ClE_0 = NIM_NIL;
		nimZeroMem((void*)(&T12_), sizeof(tyProc__HzVCwACFYM9cx9aV62PdjtuA));
		T12_.ClP_0 = colonanonymous___main_437; T12_.ClE_0 = colonenv_;
		s = llStreamOpenStdIn__llstream_85(T11_, T12_);
		T13_ = (NIM_BOOL)0;
		T13_ = processModule__passes_213((*colonenv_).graph1, m, idgen, s);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandJsonScript__main_398)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = jsonBuildInstructionsFile__extccomp_1488((*graph).config);
	runJsonBuildInstructions__extccomp_2595((*graph).config, T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, mainCommand__main_504)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph) {
	tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ* colonenv_;
	tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
	NI T1_;
	NimStringDesc* T2_;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ*) newObj((&NTIrefobject__KUEg0d7nz9cN9a2XtSOdwk6Q_), sizeof(tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ));
	(*colonenv_).Sup.m_type = (&NTIobject__jLKPtdbDCz7KEj3NDIo2qQ_);
	asgnRef((void**) (&(*colonenv_).graph2), graph);
	asgnRef((void**) (&(*colonenv_).conf1), (*(*colonenv_).graph2).config);
	cache = (*(*colonenv_).graph2).cache;
	clearPasses__passes_57((*colonenv_).graph2);
	(*(*colonenv_).conf1).lastCmdTime = epochTime__pureZtimes_3608();
	asgnRef((void**) (&(*(*colonenv_).conf1).searchPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*(*colonenv_).conf1).searchPaths), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
	T1_ = (*(*colonenv_).conf1).searchPaths->Sup.len++;
	T2_ = NIM_NIL;
	T2_ = (*(*colonenv_).conf1).searchPaths->data[T1_]; (*(*colonenv_).conf1).searchPaths->data[T1_] = copyStringRC1((*(*colonenv_).conf1).libpath);
	if (T2_) nimGCunrefNoCycle(T2_);
	{
		if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 6))) goto LA5_;
		(*(*colonenv_).conf1).globalOptions = ((*(*colonenv_).conf1).globalOptions | 12288);
	}
	LA5_: ;
	{
		tyProc__h8IxK5anTqQTXvJUUElS3Q T11_;
		if (!!(((252 &((NU32)1<<((NU)((*(*colonenv_).conf1).cmd)&31U)))!=0))) goto LA9_;
		nimZeroMem((void*)(&T11_), sizeof(tyProc__h8IxK5anTqQTXvJUUElS3Q));
		T11_.ClP_0 = customizeForBackend__main_512; T11_.ClE_0 = colonenv_;
		T11_.ClE_0? T11_.ClP_0(((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 1), T11_.ClE_0):((TM__hz3sEVFduMjVvdBnJCwMHA_6)(T11_.ClP_0))(((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 1));
	}
	LA9_: ;
	{
		NIM_BOOL T14_;
		NimStringDesc* ret;
		NimStringDesc* T31_;
		T14_ = (NIM_BOOL)0;
		T14_ = isEmpty__pathutils_94((*(*colonenv_).conf1).outDir);
		if (!T14_) goto LA15_;
		{
			if (!(((*(*colonenv_).conf1).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 13))&63U)))!=0)) goto LA19_;
			ret = getNimcacheDir__options_4185((*colonenv_).conf1);
		}
		goto LA17_;
		LA19_: ;
		{
			ret = copyString((*(*colonenv_).conf1).projectPath);
		}
		LA17_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = nosisAbsolute(ret);
			if (!!(T24_)) goto LA25_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_7));
		}
		LA25_: ;
		{
			if (!((4186112 &((NU32)1<<((NU)((*(*colonenv_).conf1).cmd)&31U)))!=0)) goto LA29_;
			ret = slash___pathutils_112(ret, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_8));
		}
		LA29_: ;
		T31_ = NIM_NIL;
		T31_ = (*(*colonenv_).conf1).outDir; (*(*colonenv_).conf1).outDir = copyStringRC1(ret);
		if (T31_) nimGCunrefNoCycle(T31_);
	}
	LA15_: ;
	switch ((*(*colonenv_).conf1).cmd) {
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 2) ... ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 6):
	{
		tyProc__HzVCwACFYM9cx9aV62PdjtuA T33_;
		nimZeroMem((void*)(&T33_), sizeof(tyProc__HzVCwACFYM9cx9aV62PdjtuA));
		T33_.ClP_0 = compileToBackend__main_534; T33_.ClE_0 = colonenv_;
		T33_.ClE_0? T33_.ClP_0(T33_.ClE_0):((TM__hz3sEVFduMjVvdBnJCwMHA_21)(T33_.ClP_0))();
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 7):
	{
		liMessage__msgs_1128((*colonenv_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_22), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__hz3sEVFduMjVvdBnJCwMHA_23, NIM_FALSE);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 13):
	{
		NimStringDesc* docConfX60gensym37_;
		wantMainModule__modules_1209((*colonenv_).conf1);
		{
			if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15))) goto LA38_;
			docConfX60gensym37_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_25));
		}
		goto LA36_;
		LA38_: ;
		{
			docConfX60gensym37_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_26));
		}
		LA36_: ;
		loadConfigs__nimconf_267(docConfX60gensym37_, cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
		defineSymbol__condsyms_4((*(*colonenv_).conf1).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_27), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
		commandDoc__docgen_7231(cache, (*colonenv_).conf1);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 14):
	{
		NimStringDesc* docConfX60gensym38_;
		wantMainModule__modules_1209((*colonenv_).conf1);
		{
			if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15))) goto LA44_;
			docConfX60gensym38_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_25));
		}
		goto LA42_;
		LA44_: ;
		{
			docConfX60gensym38_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_26));
		}
		LA42_: ;
		loadConfigs__nimconf_267(docConfX60gensym38_, cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
		defineSymbol__condsyms_4((*(*colonenv_).conf1).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_27), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
		setNoteDefaults__options_483((*colonenv_).conf1, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 53), NIM_FALSE);
		setNoteDefaults__options_483((*colonenv_).conf1, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 26), NIM_FALSE);
		commandDoc2__main_338((*colonenv_).graph2, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_30));
		{
			NIM_BOOL T49_;
			NimStringDesc* T53_;
			T49_ = (NIM_BOOL)0;
			T49_ = (((*(*colonenv_).conf1).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 27))&63U)))!=0);
			if (!(T49_)) goto LA50_;
			T49_ = (((*(*colonenv_).conf1).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 33))&63U)))!=0);
			LA50_: ;
			if (!T49_) goto LA51_;
			T53_ = NIM_NIL;
			T53_ = dollar___options_4472((*(*colonenv_).conf1).outDir);
			commandBuildIndex__docgen_7310((*colonenv_).conf1, T53_, ((NimStringDesc*) NIM_NIL));
		}
		LA51_: ;
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 16):
	{
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ warn;
			tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ colontmp_;
			NI i;
			warn = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
			nimZeroMem((void*)colontmp_, sizeof(tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ));
			nimCopyMem((void*)colontmp_, (NIM_CONST void*)TM__hz3sEVFduMjVvdBnJCwMHA_32, 14);
			i = ((NI) 0);
			{
				while (1) {
					if (!(i <= ((NI) 106))) goto LA57;
					{
						if (!((colontmp_[(NU)(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i)))>>3] &(1U<<((NU)(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i)))&7U)))!=0)) goto LA60_;
						warn = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i));
						setNoteDefaults__options_483((*colonenv_).conf1, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (warn)), NIM_TRUE);
					}
					LA60_: ;
					i += ((NI) 1);
				} LA57: ;
			}
		}
		setNoteDefaults__options_483((*colonenv_).conf1, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 26), NIM_FALSE);
		loadConfigs__nimconf_267(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_26), cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
		commandRst2Html__docgen_7261(cache, (*colonenv_).conf1);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 17):
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15):
	{
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ warn_2;
			tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ colontmp__2;
			NI i_2;
			warn_2 = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
			nimZeroMem((void*)colontmp__2, sizeof(tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ));
			nimCopyMem((void*)colontmp__2, (NIM_CONST void*)TM__hz3sEVFduMjVvdBnJCwMHA_32, 14);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 <= ((NI) 106))) goto LA65;
					{
						if (!((colontmp__2[(NU)(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i_2)))>>3] &(1U<<((NU)(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i_2)))&7U)))!=0)) goto LA68_;
						warn_2 = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i_2));
						setNoteDefaults__options_483((*colonenv_).conf1, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (warn_2)), NIM_TRUE);
					}
					LA68_: ;
					i_2 += ((NI) 1);
				} LA65: ;
			}
		}
		{
			if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 17))) goto LA72_;
			loadConfigs__nimconf_267(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_25), cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
			commandRst2TeX__docgen_7264(cache, (*colonenv_).conf1);
		}
		goto LA70_;
		LA72_: ;
		{
			NimStringDesc* docConfX60gensym41_;
			wantMainModule__modules_1209((*colonenv_).conf1);
			{
				if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15))) goto LA77_;
				docConfX60gensym41_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_25));
			}
			goto LA75_;
			LA77_: ;
			{
				docConfX60gensym41_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_26));
			}
			LA75_: ;
			loadConfigs__nimconf_267(docConfX60gensym41_, cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
			defineSymbol__condsyms_4((*(*colonenv_).conf1).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_27), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
			commandDoc2__main_338((*colonenv_).graph2, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_28));
		}
		LA70_: ;
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 18):
	{
		NimStringDesc* docConfX60gensym42_;
		wantMainModule__modules_1209((*colonenv_).conf1);
		{
			if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15))) goto LA83_;
			docConfX60gensym42_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_25));
		}
		goto LA81_;
		LA83_: ;
		{
			docConfX60gensym42_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_26));
		}
		LA81_: ;
		loadConfigs__nimconf_267(docConfX60gensym42_, cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
		defineSymbol__condsyms_4((*(*colonenv_).conf1).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_27), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
		commandJson__docgen_7267(cache, (*colonenv_).conf1);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 19):
	{
		NimStringDesc* docConfX60gensym43_;
		wantMainModule__modules_1209((*colonenv_).conf1);
		{
			if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15))) goto LA89_;
			docConfX60gensym43_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_25));
		}
		goto LA87_;
		LA89_: ;
		{
			docConfX60gensym43_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_26));
		}
		LA87_: ;
		loadConfigs__nimconf_267(docConfX60gensym43_, cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
		defineSymbol__condsyms_4((*(*colonenv_).conf1).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_27), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
		commandDoc2__main_338((*colonenv_).graph2, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_29));
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 20):
	{
		NimStringDesc* docConfX60gensym44_;
		wantMainModule__modules_1209((*colonenv_).conf1);
		{
			if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15))) goto LA95_;
			docConfX60gensym44_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_25));
		}
		goto LA93_;
		LA95_: ;
		{
			docConfX60gensym44_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_26));
		}
		LA93_: ;
		loadConfigs__nimconf_267(docConfX60gensym44_, cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
		defineSymbol__condsyms_4((*(*colonenv_).conf1).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_27), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
		commandTags__docgen_7289(cache, (*colonenv_).conf1);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 21):
	{
		NimStringDesc* docConfX60gensym45_;
		NimStringDesc* T104_;
		wantMainModule__modules_1209((*colonenv_).conf1);
		{
			if (!((*(*colonenv_).conf1).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15))) goto LA101_;
			docConfX60gensym45_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_25));
		}
		goto LA99_;
		LA101_: ;
		{
			docConfX60gensym45_ = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_26));
		}
		LA99_: ;
		loadConfigs__nimconf_267(docConfX60gensym45_, cache, (*colonenv_).conf1, (*(*colonenv_).graph2).idgen);
		defineSymbol__condsyms_4((*(*colonenv_).conf1).symbols, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_27), ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_3));
		T104_ = NIM_NIL;
		T104_ = dollar___options_4370((*(*colonenv_).conf1).projectFull);
		commandBuildIndex__docgen_7310((*colonenv_).conf1, T104_, (*(*colonenv_).conf1).outFile);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 22):
	{
		commandGenDepend__main_307((*colonenv_).graph2);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 23):
	{
		{
			NimStringDesc* T109_;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* definedSymbols;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* libpaths;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* lazyPaths;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* hints;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* warnings;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* dumpdata;
			tyArray__z9aSJuvfp9bpSH4mIjAf4YJw T144_;
			NimStringDesc* T145_;
			NimStringDesc* T146_;
			NimStringDesc* T147_;
			NimStringDesc* T148_;
			T109_ = NIM_NIL;
			T109_ = getConfigVar__options_4054((*colonenv_).conf1, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_36), ((NimStringDesc*) NIM_NIL));
			if (!eqStrings(T109_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_29))) goto LA110_;
			wantMainModule__modules_1209((*colonenv_).conf1);
			definedSymbols = newJArray__pureZjson_133();
			{
				NimStringDesc* s;
				s = NIM_NIL;
				{
					NimStringDesc* key;
					NimStringDesc* val;
					key = NIM_NIL;
					val = NIM_NIL;
					{
						NI h;
						NI colontmp__3;
						NI T115_;
						NI res;
						h = (NI)0;
						colontmp__3 = (NI)0;
						T115_ = (((*(*(*colonenv_).conf1).symbols).data ? (*(*(*colonenv_).conf1).symbols).data->Sup.len : 0)-1);
						colontmp__3 = T115_;
						res = ((NI) 0);
						{
							while (1) {
								if (!(res <= colontmp__3)) goto LA117;
								h = res;
								{
									tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T122_;
									NI T123_;
									if (!(*(*(*colonenv_).conf1).symbols).data->data[h].Field2) goto LA120_;
									key = (*(*(*colonenv_).conf1).symbols).data->data[h].Field0;
									val = (*(*(*colonenv_).conf1).symbols).data->data[h].Field1;
									s = key;
									T122_ = NIM_NIL;
									T122_ = percent___pureZjson_1809(s);
									asgnRef((void**) (&(*definedSymbols)._kind_7.elems), (tySequence__qIo1GWQhO9cOgsAJDKUY8kw*) incrSeqV3((TGenericSeq*)((*definedSymbols)._kind_7.elems), (&NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_)));
									T123_ = (*definedSymbols)._kind_7.elems->Sup.len++;
									asgnRef((void**) (&(*definedSymbols)._kind_7.elems->data[T123_]), T122_);
								}
								LA120_: ;
								res += ((NI) 1);
							} LA117: ;
						}
					}
				}
			}
			libpaths = newJArray__pureZjson_133();
			lazyPaths = newJArray__pureZjson_133();
			{
				NimStringDesc** dir;
				NI i_3;
				NI L;
				NI T125_;
				dir = (NimStringDesc**)0;
				i_3 = ((NI) 0);
				T125_ = ((*(*colonenv_).conf1).searchPaths ? (*(*colonenv_).conf1).searchPaths->Sup.len : 0);
				L = T125_;
				{
					while (1) {
						tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T128_;
						NI T129_;
						if (!(i_3 < L)) goto LA127;
						dir = (&(*(*colonenv_).conf1).searchPaths->data[i_3]);
						T128_ = NIM_NIL;
						T128_ = percent___pureZjson_1809((*dir));
						asgnRef((void**) (&(*libpaths)._kind_7.elems), (tySequence__qIo1GWQhO9cOgsAJDKUY8kw*) incrSeqV3((TGenericSeq*)((*libpaths)._kind_7.elems), (&NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_)));
						T129_ = (*libpaths)._kind_7.elems->Sup.len++;
						asgnRef((void**) (&(*libpaths)._kind_7.elems->data[T129_]), T128_);
						i_3 += ((NI) 1);
					} LA127: ;
				}
			}
			{
				NimStringDesc** dir_2;
				NI i_4;
				NI L_2;
				NI T131_;
				dir_2 = (NimStringDesc**)0;
				i_4 = ((NI) 0);
				T131_ = ((*(*colonenv_).conf1).lazyPaths ? (*(*colonenv_).conf1).lazyPaths->Sup.len : 0);
				L_2 = T131_;
				{
					while (1) {
						tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T134_;
						NI T135_;
						if (!(i_4 < L_2)) goto LA133;
						dir_2 = (&(*(*colonenv_).conf1).lazyPaths->data[i_4]);
						T134_ = NIM_NIL;
						T134_ = percent___pureZjson_1809((*dir_2));
						asgnRef((void**) (&(*lazyPaths)._kind_7.elems), (tySequence__qIo1GWQhO9cOgsAJDKUY8kw*) incrSeqV3((TGenericSeq*)((*lazyPaths)._kind_7.elems), (&NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_)));
						T135_ = (*lazyPaths)._kind_7.elems->Sup.len++;
						asgnRef((void**) (&(*lazyPaths)._kind_7.elems->data[T135_]), T134_);
						i_4 += ((NI) 1);
					} LA133: ;
				}
			}
			hints = newJObject__pureZjson_102();
			{
				tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ a;
				NI res_2;
				a = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
				res_2 = ((NI) 72);
				{
					while (1) {
						tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T139_;
						if (!(res_2 <= ((NI) 106))) goto LA138;
						a = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (res_2));
						T139_ = NIM_NIL;
						T139_ = percent___pureZjson_1835((((*(*colonenv_).conf1).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (a))- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (a))- 17))&7U)))!=0));
						X5BX5Deq___pureZjson_1942(hints, reprEnum((NI)a, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)), T139_);
						res_2 += ((NI) 1);
					} LA138: ;
				}
			}
			warnings = newJObject__pureZjson_102();
			{
				tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ a_2;
				NI res_3;
				a_2 = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
				res_3 = ((NI) 17);
				{
					while (1) {
						tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T143_;
						if (!(res_3 <= ((NI) 71))) goto LA142;
						a_2 = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (res_3));
						T143_ = NIM_NIL;
						T143_ = percent___pureZjson_1835((((*(*colonenv_).conf1).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (a_2))- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (a_2))- 17))&7U)))!=0));
						X5BX5Deq___pureZjson_1942(warnings, reprEnum((NI)a_2, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)), T143_);
						res_3 += ((NI) 1);
					} LA142: ;
				}
			}
			nimZeroMem((void*)T144_, sizeof(tyArray__z9aSJuvfp9bpSH4mIjAf4YJw));
			T144_[0].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_37));
			T144_[0].Field1 = percent___pureZjson_1809(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_38));
			T144_[1].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_39));
			T145_ = NIM_NIL;
			T145_ = nosgetAppFilename();
			T144_[1].Field1 = percent___pureZjson_1809(T145_);
			T144_[2].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_40));
			T146_ = NIM_NIL;
			T146_ = getPrefixDir__options_4096((*colonenv_).conf1);
			T144_[2].Field1 = percent___pureZjson_1809(T146_);
			T144_[3].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_41));
			T144_[3].Field1 = percent___pureZjson_1809((*(*colonenv_).conf1).libpath);
			T144_[4].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_42));
			T144_[4].Field1 = percent___pureZjson_1809((*(*colonenv_).conf1).projectFull);
			T144_[5].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_43));
			T144_[5].Field1 = definedSymbols;
			T144_[6].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_44));
			T144_[6].Field1 = libpaths;
			T144_[7].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_45));
			T144_[7].Field1 = lazyPaths;
			T144_[8].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_46));
			T144_[8].Field1 = percent___pureZjson_1809((*(*colonenv_).conf1).outDir);
			T144_[9].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_47));
			T144_[9].Field1 = percent___pureZjson_1809((*(*colonenv_).conf1).outFile);
			T144_[10].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_48));
			T147_ = NIM_NIL;
			T147_ = getNimcacheDir__options_4185((*colonenv_).conf1);
			T144_[10].Field1 = percent___pureZjson_1809(T147_);
			T144_[11].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_49));
			T144_[11].Field1 = hints;
			T144_[12].Field0 = copyString(((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_50));
			T144_[12].Field1 = warnings;
			dumpdata = percent___pureZjson_1838(T144_, 13);
			T148_ = NIM_NIL;
			T148_ = dollar___pureZjson_4484(dumpdata);
			msgWriteln__msgs_657((*colonenv_).conf1, T148_, 7);
		}
		goto LA107_;
		LA110_: ;
		{
			msgWriteln__msgs_657((*colonenv_).conf1, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_51), 7);
			{
				NimStringDesc* s_2;
				s_2 = NIM_NIL;
				{
					NimStringDesc* key_2;
					NimStringDesc* val_2;
					key_2 = NIM_NIL;
					val_2 = NIM_NIL;
					{
						NI h_2;
						NI colontmp__4;
						NI T153_;
						NI res_4;
						h_2 = (NI)0;
						colontmp__4 = (NI)0;
						T153_ = (((*(*(*colonenv_).conf1).symbols).data ? (*(*(*colonenv_).conf1).symbols).data->Sup.len : 0)-1);
						colontmp__4 = T153_;
						res_4 = ((NI) 0);
						{
							while (1) {
								if (!(res_4 <= colontmp__4)) goto LA155;
								h_2 = res_4;
								{
									if (!(*(*(*colonenv_).conf1).symbols).data->data[h_2].Field2) goto LA158_;
									key_2 = (*(*(*colonenv_).conf1).symbols).data->data[h_2].Field0;
									val_2 = (*(*(*colonenv_).conf1).symbols).data->data[h_2].Field1;
									s_2 = key_2;
									msgWriteln__msgs_657((*colonenv_).conf1, s_2, 7);
								}
								LA158_: ;
								res_4 += ((NI) 1);
							} LA155: ;
						}
					}
				}
			}
			msgWriteln__msgs_657((*colonenv_).conf1, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_52), 3);
			{
				NimStringDesc** it;
				NI i_5;
				NI L_3;
				NI T161_;
				it = (NimStringDesc**)0;
				i_5 = ((NI) 0);
				T161_ = ((*(*colonenv_).conf1).searchPaths ? (*(*colonenv_).conf1).searchPaths->Sup.len : 0);
				L_3 = T161_;
				{
					while (1) {
						if (!(i_5 < L_3)) goto LA163;
						it = (&(*(*colonenv_).conf1).searchPaths->data[i_5]);
						msgWriteln__msgs_657((*colonenv_).conf1, (*it), 0);
						i_5 += ((NI) 1);
					} LA163: ;
				}
			}
		}
		LA107_: ;
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8):
	{
		commandCheck__main_310((*colonenv_).graph2);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 9):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T166_;
		wantMainModule__modules_1209((*colonenv_).conf1);
		T166_ = NIM_NIL;
		T166_ = parseFile__syntaxes_217((*(*colonenv_).conf1).projectMainIdx, cache, (*colonenv_).conf1);
		(void)(T166_);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 10):
	{
		wantMainModule__modules_1209((*colonenv_).conf1);
		commandView__main_463((*colonenv_).graph2);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 24):
	{
		commandInteractive__main_409((*colonenv_).graph2);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 12):
	{
		{
			NIM_BOOL T172_;
			T172_ = (NIM_BOOL)0;
			T172_ = (*(*colonenv_).conf1).projectIsCmd;
			if (T172_) goto LA173_;
			T172_ = (*(*colonenv_).conf1).projectIsStdin;
			LA173_: ;
			if (!T172_) goto LA174_;
		}
		goto LA170_;
		LA174_: ;
		{
			NIM_BOOL T177_;
			NimStringDesc* T180_;
			T177_ = (NIM_BOOL)0;
			T177_ = nosfileExists((*(*colonenv_).conf1).projectFull);
			if (!!(T177_)) goto LA178_;
			T180_ = NIM_NIL;
			T180_ = rawNewString(((*(*colonenv_).conf1).projectFull ? (*(*colonenv_).conf1).projectFull->Sup.len : 0) + 31);
appendString(T180_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_59));
appendString(T180_, (*(*colonenv_).conf1).projectFull);
			liMessage__msgs_1128((*colonenv_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T180_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__hz3sEVFduMjVvdBnJCwMHA_60, NIM_FALSE);
		}
		goto LA170_;
		LA178_: ;
		LA170_: ;
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 25):
	{
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 26):
	{
		setOutFile__main_474((*(*colonenv_).graph2).config);
		commandJsonScript__main_398((*colonenv_).graph2);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 1):
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 0):
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 11):
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 27):
	{
		NimStringDesc* T184_;
		T184_ = NIM_NIL;
		T184_ = rawNewString(((*(*colonenv_).conf1).command ? (*(*colonenv_).conf1).command->Sup.len : 0) + 17);
appendString(T184_, ((NimStringDesc*) &TM__hz3sEVFduMjVvdBnJCwMHA_61));
appendString(T184_, (*(*colonenv_).conf1).command);
		liMessage__msgs_1128((*colonenv_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T184_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__hz3sEVFduMjVvdBnJCwMHA_62, NIM_FALSE);
	}
	break;
	}
	{
		NIM_BOOL T187_;
		T187_ = (NIM_BOOL)0;
		T187_ = ((*(*colonenv_).conf1).errorCounter == ((NI) 0));
		if (!(T187_)) goto LA188_;
		T187_ = !(((41943168 &((NU32)1<<((NU)((*(*colonenv_).conf1).cmd)&31U)))!=0));
		LA188_: ;
		if (!T187_) goto LA189_;
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T195_;
			if (!(((*(*colonenv_).conf1).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 50))&63U)))!=0)) goto LA193_;
			nimZeroMem((void*)T195_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T195_[0] = dump__vmprofiler_697((*colonenv_).conf1, (*(*colonenv_).conf1).vmProfileData);
			echoBinSafe(T195_, 1);
		}
		LA193_: ;
		genSuccessX__msgs_1537((*colonenv_).conf1);
	}
	LA189_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmmaindotnim_DatInit000)(void) {
static TNimNode* TM__hz3sEVFduMjVvdBnJCwMHA_2_3[3];
static TNimNode* TM__hz3sEVFduMjVvdBnJCwMHA_57_2[2];
static TNimNode TM__hz3sEVFduMjVvdBnJCwMHA_0[7];
NTIobject__jLKPtdbDCz7KEj3NDIo2qQ_.size = sizeof(tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ);
NTIobject__jLKPtdbDCz7KEj3NDIo2qQ_.align = NIM_ALIGNOF(tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ);
NTIobject__jLKPtdbDCz7KEj3NDIo2qQ_.kind = 17;
NTIobject__jLKPtdbDCz7KEj3NDIo2qQ_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__hz3sEVFduMjVvdBnJCwMHA_2_3[0] = &TM__hz3sEVFduMjVvdBnJCwMHA_0[1];
TM__hz3sEVFduMjVvdBnJCwMHA_0[1].kind = 1;
TM__hz3sEVFduMjVvdBnJCwMHA_0[1].offset = offsetof(tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ, colonstate_);
TM__hz3sEVFduMjVvdBnJCwMHA_0[1].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__hz3sEVFduMjVvdBnJCwMHA_0[1].name = ":state";
TM__hz3sEVFduMjVvdBnJCwMHA_2_3[1] = &TM__hz3sEVFduMjVvdBnJCwMHA_0[2];
TM__hz3sEVFduMjVvdBnJCwMHA_0[2].kind = 1;
TM__hz3sEVFduMjVvdBnJCwMHA_0[2].offset = offsetof(tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ, conf1);
TM__hz3sEVFduMjVvdBnJCwMHA_0[2].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__hz3sEVFduMjVvdBnJCwMHA_0[2].name = "conf1";
TM__hz3sEVFduMjVvdBnJCwMHA_2_3[2] = &TM__hz3sEVFduMjVvdBnJCwMHA_0[3];
TM__hz3sEVFduMjVvdBnJCwMHA_0[3].kind = 1;
TM__hz3sEVFduMjVvdBnJCwMHA_0[3].offset = offsetof(tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ, graph2);
TM__hz3sEVFduMjVvdBnJCwMHA_0[3].typ = (&NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_);
TM__hz3sEVFduMjVvdBnJCwMHA_0[3].name = "graph2";
TM__hz3sEVFduMjVvdBnJCwMHA_0[0].len = 3; TM__hz3sEVFduMjVvdBnJCwMHA_0[0].kind = 2; TM__hz3sEVFduMjVvdBnJCwMHA_0[0].sons = &TM__hz3sEVFduMjVvdBnJCwMHA_2_3[0];
NTIobject__jLKPtdbDCz7KEj3NDIo2qQ_.node = &TM__hz3sEVFduMjVvdBnJCwMHA_0[0];
NTIrefobject__KUEg0d7nz9cN9a2XtSOdwk6Q_.size = sizeof(tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ*);
NTIrefobject__KUEg0d7nz9cN9a2XtSOdwk6Q_.align = NIM_ALIGNOF(tyObject_Env_maindotnim_mainCommand___jLKPtdbDCz7KEj3NDIo2qQ*);
NTIrefobject__KUEg0d7nz9cN9a2XtSOdwk6Q_.kind = 22;
NTIrefobject__KUEg0d7nz9cN9a2XtSOdwk6Q_.base = (&NTIobject__jLKPtdbDCz7KEj3NDIo2qQ_);
NTIrefobject__KUEg0d7nz9cN9a2XtSOdwk6Q_.marker = Marker_tyRef__KUEg0d7nz9cN9a2XtSOdwk6Q;
NTIobject__9a3nhy8WNV5ikCoayUArgTA_.size = sizeof(tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA);
NTIobject__9a3nhy8WNV5ikCoayUArgTA_.align = NIM_ALIGNOF(tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA);
NTIobject__9a3nhy8WNV5ikCoayUArgTA_.kind = 17;
NTIobject__9a3nhy8WNV5ikCoayUArgTA_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__hz3sEVFduMjVvdBnJCwMHA_57_2[0] = &TM__hz3sEVFduMjVvdBnJCwMHA_0[5];
TM__hz3sEVFduMjVvdBnJCwMHA_0[5].kind = 1;
TM__hz3sEVFduMjVvdBnJCwMHA_0[5].offset = offsetof(tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA, colonstate_);
TM__hz3sEVFduMjVvdBnJCwMHA_0[5].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__hz3sEVFduMjVvdBnJCwMHA_0[5].name = ":state";
TM__hz3sEVFduMjVvdBnJCwMHA_57_2[1] = &TM__hz3sEVFduMjVvdBnJCwMHA_0[6];
TM__hz3sEVFduMjVvdBnJCwMHA_0[6].kind = 1;
TM__hz3sEVFduMjVvdBnJCwMHA_0[6].offset = offsetof(tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA, graph1);
TM__hz3sEVFduMjVvdBnJCwMHA_0[6].typ = (&NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_);
TM__hz3sEVFduMjVvdBnJCwMHA_0[6].name = "graph1";
TM__hz3sEVFduMjVvdBnJCwMHA_0[4].len = 2; TM__hz3sEVFduMjVvdBnJCwMHA_0[4].kind = 2; TM__hz3sEVFduMjVvdBnJCwMHA_0[4].sons = &TM__hz3sEVFduMjVvdBnJCwMHA_57_2[0];
NTIobject__9a3nhy8WNV5ikCoayUArgTA_.node = &TM__hz3sEVFduMjVvdBnJCwMHA_0[4];
NTIrefobject__BnTY2dJNiqeO8iju2BInZw_.size = sizeof(tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA*);
NTIrefobject__BnTY2dJNiqeO8iju2BInZw_.align = NIM_ALIGNOF(tyObject_Env_maindotnim_commandInteractive___9a3nhy8WNV5ikCoayUArgTA*);
NTIrefobject__BnTY2dJNiqeO8iju2BInZw_.kind = 22;
NTIrefobject__BnTY2dJNiqeO8iju2BInZw_.base = (&NTIobject__9a3nhy8WNV5ikCoayUArgTA_);
NTIrefobject__BnTY2dJNiqeO8iju2BInZw_.marker = Marker_tyRef__BnTY2dJNiqeO8iju2BInZw;
}

